@@ -280,8 +280,10 @@
 
 "trend.spatial" <-
   function (trend, geodata, add.to.trend) 
-{
+{  
   if(!missing(geodata)){
+    if(class(geodata) %in% ls(pattern=glob2rx("Spatial*DataFrame"), pos="package:sp"))
+        geodata <- geodata@data
     attach(geodata, pos=2, warn.conflicts=FALSE)
     if(!is.null(geodata$covariate)){
       attach(geodata$covariate, pos=3, warn.conflicts=FALSE)
